Ataskaitos | OiRA

Temos

# Ataskaitos

Ataskaita skirta:

- pateikti įrodymus priežiūros tarnyboms;
- pateikti informaciją susijusiems asmenims (darbuotojams, darbo saugos institucijų atstovams, darbdaviams, darbuotojų saugos ir sveikatos specialistams ir kt.);
- stebėti ir įvertinti, ar imtasi būtinų priemonių;
- įrašyti pokyčius, pasikeitus aplinkybėms (nauja įranga ir (arba) nauji darbuotojai, pateiktos nelaimingų atsitikimų tyrimų išvados ar pan.).

Ataskaitą galite išsaugoti savo kompiuteryje ir atspausdinti. Ją taip pat galite keisti arba papildyti. Atkreipiame dėmesį, kad atsisiųstoje ataskaitoje padaryti pakeitimai OiRA priemonėje NEIŠSAUGOMI.

## Ataskaitų pasirinkimai

Skirtingoms reikmėms rengiamos skirtingos atskaitos. Konkrečiose priemonėse pateikiamų ataskaitų pasirinkimas priklauso nuo nacionalinio OiRA partnerio ir (arba) priemonės kūrėjo priimtų sprendimų.

Galimos ataskaitos

### Išsami ataskaita

Formatas: Word / Office Open XML (.docx). Atsisiuntus galima redaguoti.

Ataskaitos turinys: visa informacija ir duomenys, kuriuos įvedėte rizikos vertinimo proceso metu.

Skirta: rizikos vertinimo įrodymams teikti priežiūros tarnyboms (pvz., darbo inspekcijai).

### Veiksmų planas

Formatas: Excel / Office Open XML (.xlsx). Atsisiuntus galima redaguoti.

Ataskaitos turinys: informacija apie visas priemones, kurias nusprendėte įgyvendinti.

Skirta:

- aktyviai stebėti jūsų pasirinktų priemonių įgyvendinimą;
- problemoms ir (arba) rizikai darbo vietoje valdyti (konkrečios užduotys, kompetencijos, atsakomybės sritys, terminai).

### Rizikos veiksnių apžvalga

Formatas: Nešiojamo dokumento formatas (.pdf) Atsisiuntus redaguoti negalima.

Ataskaitos turinys: nustatytų rizikos veiksnių apžvalga.

Skirta:

- rizikos veiksnių būklei jūsų darbo vietoje apžvelgti;
- informacijai susijusiems asmenims perduoti;
- stebėti, ar tinkamai sprendžiami su rizika / priemonių įgyvendinimu susiję klausimai.

### Priemonių apžvalga

Formatas: Nešiojamo dokumento formatas (.pdf) Atsisiuntus redaguoti negalima.

Ataskaitos turinys: glausta įgyvendintinų priemonių apžvalga.

Skirta:

- glaustai priemonių, kurias nuspręsta įgyvendinti, apžvalgai;
- informacijos perdavimui susijusiems asmenims;
- stebėti, ar tinkamai sprendžiami su rizika / priemonių įgyvendinimu susiję klausimai.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More